@@ -717,14 +717,16 @@ static char const * const extra_usage[] = {
 };
 static sox_effect_handler_t sox_silence_effect = {
   "silence",
-  usage, extra_usage,
+  usage,
   SOX_EFF_MCHAN | SOX_EFF_MODIFY | SOX_EFF_LENGTH,
   sox_silence_getopts,
   sox_silence_start,
   sox_silence_flow,
   sox_silence_drain,
   sox_silence_stop,
-  lsx_kill, sizeof(priv_t)
+  lsx_kill,
+  sizeof(priv_t),
+  extra_usage,
 };
 
 const sox_effect_handler_t *lsx_silence_effect_fn(void)
